@@ -5,9 +5,9 @@ PACKAGER_GITHUB_API = EnvVar("PACKAGER_GITHUB_API", "secrets.PACKAGER_GITHUB_API
 TWINE_USERNAME = EnvVar("TWINE_USERNAME", "secrets.TWINE_USERNAME")
 TWINE_PASSWORD = EnvVar("TWINE_PASSWORD", "secrets.TWINE_PASSWORD")
 
-# from generalpackager.api.local_repo import LocalRepo
-# from generalpackager.api.local_module import LocalModule
-# from generalpackager.api.github import GitHub
-# from generalpackager.api.pypi import PyPI
 from generalpackager.packager import Packager
+from generalpackager.api.local_repo import LocalRepo
+from generalpackager.api.local_module import LocalModule
+from generalpackager.api.github import GitHub
+from generalpackager.api.pypi import PyPI
 
