@@ -1,12 +1,11 @@
 
 from generalpackager.api.shared import _SharedAPI
 from generalfile import Path
-from generallibrary import Ver, deco_cache, Recycle
+from generallibrary import Ver, deco_cache, Recycle, terminal
 
 from setuptools import find_namespace_packages
 import re
 from git import Repo
-import subprocess
 import sys
 
 
@@ -26,7 +25,7 @@ class LocalRepo(Recycle, _SharedAPI):
     name = ...
     version = "0.0.1"  # type: Ver
     description = "Missing description."
-    install_requires = []
+    install_requires = ["generallibrary"]
     extras_require = {}
     topics = []
     manifest = []
@@ -67,7 +66,7 @@ class LocalRepo(Recycle, _SharedAPI):
 
     def write_metadata(self):
         """ Write to metadata path using current metadata values. """
-        self.get_metadata_path().write(self.get_metadata_dict(), overwrite=True)
+        self.get_metadata_path().write(self.get_metadata_dict(), overwrite=True, indent=4)
 
     def exists(self):
         """ Return whether this API's target exists. """
@@ -181,26 +180,34 @@ class LocalRepo(Recycle, _SharedAPI):
     def pip_install(self):
         """ Install this repository with pip, WITHOUT -e flag.
             Subprocess messed up -e flag compared to doing it in terminal, so use the normal one."""
-        subprocess.check_call([sys.executable, "-m", "pip", "install", str(self.path)])
+        with self.path.as_working_dir():
+            terminal("pip", "install", "-e", ".")
 
     def pip_uninstall(self):
         """ Uninstall this repository with pip."""
-        subprocess.check_call([sys.executable, "-m", "pip", "uninstall", "-y", self.name])
+        terminal("-m", "pip", "uninstall", "-y", self.name, python=True)
 
     def unittest(self):
         """ Run unittests for this repository. """
-        subprocess.check_call([sys.executable, "-m", "unittest", "discover", str(self.get_test_path())])
+        terminal("-m", "unittest", "discover", str(self.get_test_path()), python=True)
 
     def create_sdist(self):
         """ Create source distribution. """
         with self.path.as_working_dir():
-            subprocess.check_call([sys.executable, "setup.py", "sdist", "bdist_wheel"])
+            terminal("setup.py", "sdist", "bdist_wheel", python=True)
 
     def upload(self):
-        """ Upload local repo to PyPI. """
+        """ Upload local repo to PyPI.
+            Todo: Make sure twine is installed when trying to upload to pypi. """
         self.create_sdist()
         with self.path.as_working_dir():
-            subprocess.check_call([sys.executable, "-m", "twine", "upload", "dist/*"])
+            terminal("-m", "twine", "upload", "dist/*", python=True)
+
+    def generate_exe(self, file_path, suppress=False):
+        """ Generate an exe file for target file_path python file. """
+        with self.path.as_working_dir():
+            terminal("-m", "PyInstaller", file_path, "--onefile", "--windowed", python=True, suppress=suppress)
+            # terminal("-m", "PyInstaller", file_path, "--onefile", "--windowed", "--name", self.name, python=True, suppress=suppress)  # Failed for some reason
 
 for key in LocalRepo.metadata_keys:
     value = getattr(LocalRepo, key)
