@@ -53,7 +53,7 @@ class _PackagerMarkdown:
         """ :param generalpackager.Packager self: """
         todos = []
         for name, objInfo in self.get_untested_objInfo_dict().items():  # type: ObjInfo
-            text = f"UnitTest for {repr(objInfo)}"
+            text = f"[UnitTest] for {repr(objInfo)}"
             path = objInfo.file(relative=True)
             line = objInfo.get_definition_line()
             todos.append(self._create_todo_dict(text=text, path=path, line=line))
@@ -96,7 +96,7 @@ class _PackagerMarkdown:
         for packager in packagers:
             attrs = packager._get_attributes_view().count("\n")
             untested_attrs = len(packager.get_untested_objInfo_dict())
-            test_percentage = floor((attrs - untested_attrs) / attrs * 100, 1)
+            test_percentage = floor((attrs - untested_attrs) / attrs * 100, 1) if attrs else 100
 
             list_of_dicts.append({
                 "Package": Markdown.link(text=packager.name, url=packager.github.url),
@@ -180,9 +180,16 @@ class _PackagerMarkdown:
 
         return string
 
-    @deco_cache()
     def _get_attributes_view(self):
         """ :param generalpackager.Packager self: """
+        return self._cache_get_attributes_view(self.commit_sha)
+
+    @deco_cache()
+    def _cache_get_attributes_view(self, commit_sha):
+        """ Additional method here to store seperate cache for different commit_shas
+
+            :param generalpackager.Packager self:
+            :param commit_sha: """
         return self.localmodule.objInfo.view(custom_repr=self._attr_repr, print_out=False)
 
     def get_attributes_markdown(self):
